<?php

namespace FM\Factory;

use Doctrine\ORM\EntityManager;

class ApontamentoFactory {
    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    public function getDadosCardApontamento($param) {

        $sql = "SELECT FUNC.NRFUNCIONARIO,ST.NMSETOR, FUNC.NMFUNCIONARIO, TO_CHAR(ULTIMOREGISTRO, 'DD/MM/YYYY') DATA
                FROM FCM_FUNCIONARIO FUNC
                LEFT JOIN (SELECT APON.NRFUNCIONARIO, MAX(APON.DTAPONTAMENTO) ULTIMOREGISTRO
                     FROM FCM_APONTAMENTO APON
                     GROUP BY NRFUNCIONARIO) AP
                ON FUNC.NRFUNCIONARIO = AP.NRFUNCIONARIO
                JOIN FCM_RELACFUNCSETOR REL
                ON REL.NRFUNCIONARIO = FUNC.NRFUNCIONARIO
                JOIN FCM_SETOR ST
                ON ST.NRSETOR = REL.NRSETOR {$param}
                ORDER BY NMFUNCIONARIO";
        
        $std = $this->connection->prepare($sql);
        
        $std->execute();
        return $std->fetchAll();
    }
    
    public function getDadosApontamentoInserido($paramNr) {
        $sql = "SELECT NRREGISTROHORAS, 
                        NRAPONTAMENTO, 
                        DTHRENTRADA, 
                        DTHRSAIDA, 
                        HRTEMPOREGISTRO, 
                        IDTIPORESGISTRO, 
                        IDALMOCO
                    FROM FCM_REGISTROHORAS
                    WHERE NRAPONTAMENTO = $paramNr
                    ORDER BY DTHRENTRADA,DTHRSAIDA ";
        
        $std = $this->connection->prepare($sql);
        
        $std->execute();
        return $std->fetchAll();
    }
    
    public function getDadosObservacoes($paramNr) {
        $sql = "SELECT REG.DTHRENTRADA, REG.DTHRSAIDA, REG.DSOBSREGISTRO
                FROM FCM_APONTAMENTO AP
                JOIN FCM_REGISTROHORAS REG
                ON REG.NRAPONTAMENTO = AP.NRAPONTAMENTO
                WHERE AP.NRAPONTAMENTO = :NRAPONTAMENTO";
        
        $std = $this->connection->prepare($sql);
        
        $std->execute($paramNr);
        return $std->fetchAll();
    }

    public function getIntervaloTrabalho($paramNr) {
        $sql = "SELECT HRENTRADAPADR, HRSAIDAPADR
                FROM FCM_FUNCIONARIO
                WHERE NRFUNCIONARIO = :NRFUNCIONARIO";
        
        $std = $this->connection->prepare($sql);
        
        $std->execute($paramNr);
        return $std->fetchAll();
    }
    
    public function buscaRegistrosHora($nrfuncionario) {
        $sql = "SELECT DISTINCT AP.NRAPONTAMENTO, TO_CHAR(AP.DTAPONTAMENTO, 'DD/MM/YYYY') AS DATA, 
                       AP.HRENTRADA, 
                       AP.HRSAIDA, 
                       AP.HRINTERVALO, 
                       AP.HRTRABALHADAS, 
                       AP.HRAUSENCIA, 
                       AP.HRTOTAIS, 
                       AP.IDFALTA, 
                       AP.IDAPURADO,
                       REG.DSOBSREGISTRO
                FROM FCM_APONTAMENTO AP
                JOIN FCM_REGISTROHORAS REG
                ON REG.NRAPONTAMENTO = AP.NRAPONTAMENTO
                WHERE NRFUNCIONARIO = {$nrfuncionario}
                ORDER BY DATA";
        
        $std = $this->connection->prepare($sql);
        
        $std->execute();
        return $std->fetchAll();
    }
    
    public function consultaApontamentoDia($parametro) {

        $sql = "SELECT NRAPONTAMENTO FROM FCM_APONTAMENTO
                WHERE TRUNC(DTAPONTAMENTO) = TRUNC (TO_DATE(:DTAPONTAMENTO, 'DD/MM/YYYY')) 
                AND NRFUNCIONARIO =: NRFUNCIONARIO";
        
        $std = $this->connection->prepare($sql);
        
        $std->execute($parametro);
        return $std->fetchAll();
    }
    
    public function quantidadeDeRegistros($parametro) {
        $sql = "SELECT NRAPONTAMENTO, COUNT(NRREGISTROHORAS) QUANTIDIDADE
                FROM FCM_REGISTROHORAS
                WHERE TRUNC(DTINCLUSAO) = TRUNC(TO_DATE('$parametro', 'DD/MM/YYYY'))
                GROUP BY NRAPONTAMENTO";
        
        $std = $this->connection->prepare($sql);
        
        $std->execute();
        return $std->fetchAll();
    }
    
    public function verificaRegistroHoras($paramTipo, $paramRegistro) {
        $sql = "SELECT NRREGISTROHORAS, NRAPONTAMENTO
                FROM FCM_REGISTROHORAS
                WHERE IDTIPORESGISTRO = '{$paramTipo}'
                AND NRREGISTROHORAS = '{$paramRegistro}'";
        $std = $this->connection->prepare($sql);
        
        $std->execute();
        return $std->fetchAll();
    }
    
    public function insertNovoApontamento($param) {

        $sql = "INSERT INTO FCM_APONTAMENTO(NRAPONTAMENTO, DTAPONTAMENTO, NRFUNCIONARIO, HRENTRADA, HRSAIDA, 
                                            HRINTERVALO, HRTRABALHADAS,HRAUSENCIA, HRTOTAIS, IDFALTA, IDAPURADO, 
                                            NRORG, IDATIVO, DTINCLUSAO, DTULTATU)
                                       VALUES(:NRAPONTAMENTO, TO_DATE(:DTAPONTAMENTO,'DD/MM/YY'), :NRFUNCIONARIO, :HRENTRADA, :HRSAIDA, 
                                            :HRINTERVALO, :HRTRABALHADAS, :HRAUSENCIA, :HRTOTAIS, :IDFALTA, :IDAPURADO, 
                                            :NRORG, :IDATIVO, SYSDATE, SYSDATE)";
        
        $std = $this->connection->prepare($sql);
        
        $std->execute($param);
    }
    
    public function insertRegistroHoras($param) {

        $sql = "INSERT INTO FCM_REGISTROHORAS(NRREGISTROHORAS, NRAPONTAMENTO, DTHRENTRADA, DTHRSAIDA, HRTEMPOREGISTRO, IDTIPORESGISTRO, 
                                            IDALMOCO, NRORG, IDATIVO, DTINCLUSAO, DTULTATU)
                                       VALUES(:NRREGISTROHORAS, :NRAPONTAMENTO, :DTHRENTRADA, :DTHRSAIDA,
                                              NVL(:HRTEMPOREGISTRO, ROUND(((TO_DATE(:DTHRSAIDA) - TO_DATE(:DATEENTRY))*24)*60 ,0)),
                                              :IDTIPORESGISTRO, :IDALMOCO, :NRORG, :IDATIVO,TO_DATE(:DTINCLUSAO, 'DD/MM/YYYY'), SYSDATE)";
       
        $std = $this->connection->prepare($sql);
        
        $std->execute($param);
    }
    
    public function deleteRegistroHoras($param) {

        $sql = "DELETE FCM_REGISTROHORAS
                WHERE NRREGISTROHORAS =: NRREGISTROHORAS";
       
        $std = $this->connection->prepare($sql);
        
        $std->execute($param);
    }
    
    public function deleteApontamento($param) {

        $sql = "DELETE FCM_APONTAMENTO
                WHERE NRAPONTAMENTO =: NRAPONTAMENTO";
       
        $std = $this->connection->prepare($sql);
        
        $std->execute($param);
    }
    
    public function apurarHoras($param) {
        $sql = "UPDATE FCM_APONTAMENTO
                SET 
                    HRENTRADA = :HRENTRADA, 
                    HRSAIDA = :HRSAIDA,
                    HRINTERVALO = :HRINTERVALO,
                    HRTRABALHADAS = :HRTRABALHADAS,
                    HRAUSENCIA = :HRAUSENCIA,
                    HRTOTAIS = :HRTOTAIS,
                    IDFALTA = :IDFALTA,
                    IDAPURADO = :IDAPURADO,
                    DTULTATU = SYSDATE
                WHERE NRAPONTAMENTO = :NRAPONTAMENTO";
       
        $std = $this->connection->prepare($sql);
        
        $std->execute($param);
    }
    
    public function lastEntry($nr) {

        $sql = "SELECT DTHRENTRADA
                  FROM FCM_REGISTROHORAS
                  WHERE NRREGISTROHORAS = (SELECT MAX(NRREGISTROHORAS)
                                             FROM FCM_REGISTROHORAS RH
                                             JOIN FCM_APONTAMENTO AP
                                               ON AP.NRAPONTAMENTO = RH.NRAPONTAMENTO
                                            WHERE AP.NRFUNCIONARIO = ".$nr."
                                            AND AP.IDFALTA = 'N')";

        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }

    public function buscaUltimoRegistroInserido($param) {
        $sql = "SELECT NRREGISTROHORAS, DTHRENTRADA, DTHRSAIDA, HRTEMPOREGISTRO, IDTIPORESGISTRO, IDALMOCO
                        FROM FCM_REGISTROHORAS
                          WHERE NRREGISTROHORAS = (SELECT MAX(NRREGISTROHORAS) 
                                                     FROM FCM_REGISTROHORAS 
                                                    WHERE NRAPONTAMENTO = :NRAPONTAMENTO)
                        AND TRUNC(DTINCLUSAO) = TRUNC(TO_DATE(:DTINCLUSAO, 'DD/MM/YYYY'))";

        $std = $this->connection->prepare($sql);
        $std->execute($param);
        return $std->fetchAll();
    }
    
    public function getTodayRegister($nr) {

      $sql = "SELECT COUNT(NRAPONTAMENTO) QTDAP
                FROM FCM_APONTAMENTO
               WHERE TRUNC(FCM_APONTAMENTO.DTAPONTAMENTO) = TRUNC(SYSDATE)
               AND NRFUNCIONARIO = ".$nr;

        $std = $this->connection->prepare($sql);

        $std->execute();
        return $std->fetchAll();
    }

    public function getNRAP($nr) {

      $sql = "SELECT NRAPONTAMENTO
                FROM FCM_APONTAMENTO
                WHERE TRUNC(FCM_APONTAMENTO.DTAPONTAMENTO) = TRUNC(SYSDATE)
                AND NRFUNCIONARIO = ".$nr;

        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }


    public function insertNewAppointment($parametros) {

        $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

        $std = $this->connection->prepare($sqlAlter);
        $std->execute();

        $sql = "INSERT INTO FCM_APONTAMENTO (NRAPONTAMENTO, DTAPONTAMENTO, NRFUNCIONARIO,
                  IDFALTA, IDAPURADO, IDATIVO, NRORG, DTINCLUSAO)
                  VALUES (:NRAPONTAMENTO, NVL(TO_CHAR(:DTAPONTAMENTO),SYSDATE), :NRFUNCIONARIO, :IDFALTA, :IDAPURADO,
                   'S', :NRORG, SYSDATE)";

        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function insertNewRegister($parametros) {

        $sqlAlter = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI:SS'";

        $std = $this->connection->prepare($sqlAlter);
        $std->execute();

        $sql = "INSERT INTO FCM_REGISTROHORAS (NRREGISTROHORAS, NRAPONTAMENTO, DTHRENTRADA,
                  IDTIPORESGISTRO, HRTEMPOREGISTRO, DSOBSREGISTRO, IDALMOCO, DTHRSAIDA, NRORG, IDATIVO, DTINCLUSAO)
                  VALUES (:NRREGISTROHORAS, :NRAPONTAMENTO, TO_CHAR(:DTHRENTRADA), :IDTIPORESGISTRO, NVL(:HRTEMPOREGISTRO, ROUND(((TO_DATE(:DTHRSAIDA) - TO_DATE(:DATEENTRY))*24)*60 ,0)),
                  :DSOBSREGISTRO, :IDALMOCO, TO_CHAR(:DTHRSAIDA), :NRORG, 'S', SYSDATE)";

        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function typeRegister($nr) {

        $sql = " SELECT IDTIPORESGISTRO, NRAPONTAMENTO, RPAD(DTHRENTRADA,10) AS DTHRENTRADA
                  FROM FCM_REGISTROHORAS
                  WHERE NRREGISTROHORAS = (SELECT MAX(NRREGISTROHORAS)
                                             FROM FCM_REGISTROHORAS RH
                                             JOIN FCM_APONTAMENTO AP
                                               ON AP.NRAPONTAMENTO = RH.NRAPONTAMENTO
                                            WHERE AP.NRFUNCIONARIO =".$nr."
                                            AND AP.IDFALTA = 'N')";

        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();

    }

    public function optionLunch($nr) {

        $sql = "SELECT COUNT(NRREGISTROHORAS) AS QTDALMOCO
                  FROM FCM_REGISTROHORAS
                 WHERE NRREGISTROHORAS = (SELECT MAX(NRREGISTROHORAS)
                                           FROM FCM_REGISTROHORAS RH
                                           JOIN FCM_APONTAMENTO AP
                                                             ON AP.NRAPONTAMENTO = RH.NRAPONTAMENTO
                                                          WHERE AP.NRFUNCIONARIO = ".$nr."
                                                          AND AP.IDFALTA = 'N'
                                                         AND RPAD(RH.DTHRSAIDA, 10) = TO_CHAR(SYSDATE, 'DD/MM/YYYY'))

                                 GROUP BY IDTIPORESGISTRO, IDALMOCO";

        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();

    }

    public function cardsRegisters($nr) {

      $sql = "SELECT RH.NRREGISTROHORAS, RH.DTHRENTRADA, RH.DTHRSAIDA, RH.IDALMOCO,
                CASE RH.IDTIPORESGISTRO WHEN 'E' THEN 'Entrada'
                    WHEN 'S' THEN 'Saída'
                    ELSE NULL END AS IDTIPORESGISTRO
                FROM FCM_REGISTROHORAS RH
                JOIN FCM_APONTAMENTO AP
                  ON AP.NRAPONTAMENTO = RH.NRAPONTAMENTO
                 AND AP.NRFUNCIONARIO = ".$nr."
               WHERE RPAD(RH.DTHRENTRADA,10) = TO_CHAR(SYSDATE, 'DD/MM/YYYY')
                  OR RPAD(RH.DTHRSAIDA, 10) = TO_CHAR(SYSDATE, 'DD/MM/YYYY')";

      $std = $this->connection->prepare($sql);
      $std->execute();
      return $std->fetchAll();
    }
}

?>