/* Sistemas Integrados TECNISA
   Compras e Suprimentos

Nome:  VERIFICA_INCONS_AFS

Descrio:
Rotina de verificao das inconsistncias de AFs e alm disso, validaes de limite

P_CDFILDEST  Filial Destino
P_CDFILLANC  Filial de Lanamento
P_NRAUTOFORN Nmero da AF

Criao:
10/01/2013 Marcelo Alexsandro Souza Silva

Codigos de Erros:

08 - Valor da AF acima do limite
09 - Valor das AF's no ms acima do limite
10 - Qt. Total da AF abaixo da Qt. mnima para o fornecedor.
11 - Valor Total da AF abaixo do mnimo para o fornecedor.
12 - Valor dos produtos da AF acima do limite do comprador.
13 - Valor dos produtos da AF no ms acima do limite do comprador.
14 - Qt. do produto abaixo do mnimo para o fornecedor.
15 - Qt. do Produto no atende ao arredondamento do fornecedor
16 - Produto no atende s particularidades do produto
17 - Produto comprado no  o preferencial.
18 - Qt. Total da AF abaixo da Qt. mnima para o fornecedor na regio.
19 - Valor Total da AF abaixo do mnimo para o fornecedor na regio.
20 - Qt. Minima de Cotao para o produto

*/

CREATE OR REPLACE PROCEDURE VERIFICA_INCONS_AFS
                     (P_CDFILDEST  AUTOFORNE.CDFILDEST%TYPE,
                      P_CDFILLANC  AUTOFORNE.CDFILLANC%TYPE,
                      P_NRAUTOFORN AUTOFORNE.NRAUTOFORN%TYPE)
IS
   V_COUNT_LIMITE         NUMBER;
   V_COUNT_INCONSISTENCIA NUMBER;
   V_CDCOMPRADOR          COMPRADOR.CDOPERADOR%TYPE;
   V_CDFILCENTCMP         FILIAL.CDFILCENTCMP%TYPE;
   V_IDQTCOTPROD          PARASUPRI.IDQTCOTPROD%TYPE;
   V_IDINCONSPRECSUP      PARASUPRI.IDINCONSPRECSUP%TYPE;
BEGIN
   /*Limpando inconsistencias anteriores*/
   UPDATE AUTOFORNE
      SET IDAFFORALIM = 'N', IDSITUATUAAF = NULL
    WHERE AUTOFORNE.CDFILDEST  = P_CDFILDEST
      AND AUTOFORNE.CDFILLANC  = P_CDFILLANC
      AND AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN;

   DELETE INCONS_AF
    WHERE INCONS_AF.CDFILDEST  = P_CDFILDEST
      AND INCONS_AF.CDFILLANC  = P_CDFILLANC
      AND INCONS_AF.NRAUTOFORN = P_NRAUTOFORN;

   DELETE FROM INCONS_ITAF
    WHERE INCONS_ITAF.CDFILDEST  = P_CDFILDEST
      AND INCONS_ITAF.CDFILLANC  = P_CDFILLANC
      AND INCONS_ITAF.NRAUTOFORN = P_NRAUTOFORN;

   /*Verificacao de limite de AF*/
   SELECT MAX(CDOPERADOR)
     INTO V_CDCOMPRADOR
     FROM AUTOFORNE
    WHERE AUTOFORNE.CDFILDEST  = P_CDFILDEST
      AND AUTOFORNE.CDFILLANC  = P_CDFILLANC
      AND AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN;

   SELECT COUNT(1)
     INTO V_COUNT_LIMITE
     FROM AUTOFORNE, COMPRADOR
    WHERE AUTOFORNE.CDFILDEST  = P_CDFILDEST
      AND AUTOFORNE.CDFILLANC  = P_CDFILLANC
      AND AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN
      AND AUTOFORNE.CDOPERADOR = COMPRADOR.CDOPERADOR
      AND AUTOFORNE.VRTOTALAF > COMPRADOR.VRLIMAFCOMP;

   IF V_COUNT_LIMITE > 0 THEN
      INSERT INTO INCONS_AF (CDFILDEST, CDFILLANC, NRAUTOFORN, CDINCONSAF)
      VALUES (P_CDFILDEST, P_CDFILLANC, P_NRAUTOFORN, '08');
   ELSE
      V_COUNT_LIMITE := 0;
      SELECT COUNT(1)
        INTO V_COUNT_LIMITE
      FROM COMPRADOR, AUTOFORNE,
        (SELECT SUM(VRTOTALAF) AS SOMAAF
         FROM AUTOFORNE
         WHERE  AUTOFORNE.DTMESAUTOFOR =
                       (SELECT DTMESAUTOFOR
                        FROM AUTOFORNE
                        WHERE CDFILDEST  = P_CDFILDEST
                          AND CDFILLANC  = P_CDFILLANC
                          AND NRAUTOFORN = P_NRAUTOFORN) AND
         CDFILDEST  = P_CDFILDEST AND
         CDOPERADOR = V_CDCOMPRADOR
      ) SUMVRTOTALAF
      WHERE (AUTOFORNE.CDFILDEST = P_CDFILDEST) AND
            (AUTOFORNE.CDFILLANC = P_CDFILLANC) AND
            (AUTOFORNE.NRAUTOFORN= P_NRAUTOFORN) AND
            (AUTOFORNE.CDOPERADOR = COMPRADOR.CDOPERADOR) AND
            SOMAAF > COMPRADOR.VRLIMAFMES;
      IF V_COUNT_LIMITE > 0 THEN
         INSERT INTO INCONS_AF (CDFILDEST, CDFILLANC, NRAUTOFORN, CDINCONSAF)
         VALUES (P_CDFILDEST, P_CDFILLANC, P_NRAUTOFORN, '09');
      ELSE
         V_COUNT_LIMITE := 0;
         FOR C_ITEM_LIMITE IN
            (SELECT CDPRODUTO, DTPROGENTAF, CDMARCA
               FROM ITEMAUTF
              WHERE ITEMAUTF.CDFILDEST  = P_CDFILDEST
                AND ITEMAUTF.CDFILLANC  = P_CDFILLANC
                AND ITEMAUTF.NRAUTOFORN = P_NRAUTOFORN)
         LOOP
            SELECT COUNT(1)
              INTO V_COUNT_LIMITE
            FROM LIMPRODAF, AUTOFORNE, PRODUTO, PRODUTO P,
               (SELECT
                  PRODUTO,
                  SUM(VRPRODUTO)  -
                  NVL(SUM(VRDESCONTO), 0) +
                  NVL(SUM(VRIMPOSTO), 0) AS SOMAAF
                FROM
                  (
                  SELECT
                     SUM(ITEMAUTF.QTPROGENTAF * ITEMAUTF.VRPREUNIAF) AS VRPRODUTO,
                     SUM((ITEMAUTF.QTPROGENTAF * ITEMAUTF.VRPREUNIAF *
                          ITEMAUTF.VRPERDESAF) / 100)                AS VRDESCONTO,
                     SUM(0) AS VRIMPOSTO,
                     ITEMAUTF.CDPRODUTO AS PRODUTO
                  FROM
                     ITEMAUTF
                  WHERE
                     ITEMAUTF.CDFILDEST   = P_CDFILDEST  AND
                     ITEMAUTF.CDFILLANC   = P_CDFILLANC AND
                     ITEMAUTF.NRAUTOFORN  = P_NRAUTOFORN AND
                     ITEMAUTF.CDPRODUTO   = C_ITEM_LIMITE.CDPRODUTO
                  GROUP BY ITEMAUTF.CDPRODUTO

                  UNION

                  SELECT
                     SUM(0) AS VRPRODUTO,
                     SUM(0) AS VRDESCONTO,
                     SUM(IMPITMAF.VRADIMPAF) AS VRIMPOSTO,
                     ITEMAUTF.CDPRODUTO AS PRODUTO
                  FROM
                     IMPITMAF,
                     ITEMAUTF
                  WHERE
                     IMPITMAF.CDFILDEST   = P_CDFILDEST  AND
                     IMPITMAF.CDFILLANC   = P_CDFILLANC AND
                     IMPITMAF.NRAUTOFORN  = P_NRAUTOFORN AND
                     IMPITMAF.CDFILDEST   = ITEMAUTF.CDFILDEST   AND
                     IMPITMAF.CDFILLANC   = ITEMAUTF.CDFILLANC   AND
                     IMPITMAF.NRAUTOFORN  = ITEMAUTF.NRAUTOFORN  AND
                     IMPITMAF.CDPRODUTO   = ITEMAUTF.CDPRODUTO   AND
                     IMPITMAF.CDMARCA     = ITEMAUTF.CDMARCA     AND
                     IMPITMAF.DTPROGENTAF = ITEMAUTF.DTPROGENTAF AND
                     ITEMAUTF.CDPRODUTO   = C_ITEM_LIMITE.CDPRODUTO
                  GROUP BY ITEMAUTF.CDPRODUTO

                  )
                  GROUP BY PRODUTO)

            WHERE PRODUTO.CDPRODUTO = PRODUTO AND
                  (AUTOFORNE.CDFILDEST = P_CDFILDEST) AND
                  (AUTOFORNE.CDFILLANC = P_CDFILLANC) AND
                  (AUTOFORNE.NRAUTOFORN= P_NRAUTOFORN) AND
                  AUTOFORNE.CDOPERADOR = LIMPRODAF.CDOPERADOR AND
                  P.CDPRODUTO = LIMPRODAF.CDPRODUTO AND
                  P.CDARVPROD =
                                  (SELECT MAX(PR.CDARVPROD)
                                   FROM LIMPRODAF, PRODUTO PR
                                   WHERE PR.CDPRODUTO = LIMPRODAF.CDPRODUTO AND
                                         LIMPRODAF.CDOPERADOR = V_CDCOMPRADOR AND
                                         INSTR(PRODUTO.CDARVPROD, PR.CDARVPROD)= 1) AND
                  SOMAAF > LIMPRODAF.VRLIMPRODAF;
            IF V_COUNT_LIMITE > 0 THEN
               INSERT INTO INCONS_ITAF (CDFILDEST, CDFILLANC, NRAUTOFORN, CDPRODUTO, DTPROGENTAF, CDMARCA, CDINCONSITAF)
               VALUES (P_CDFILDEST, P_CDFILLANC, P_NRAUTOFORN, C_ITEM_LIMITE.CDPRODUTO, C_ITEM_LIMITE.DTPROGENTAF, C_ITEM_LIMITE.CDMARCA, '12');
            ELSE
               SELECT COUNT(1)
                 INTO V_COUNT_LIMITE
               FROM LIMPRODAF, AUTOFORNE, PRODUTO, PRODUTO P,
                ( (SELECT
                     PRODUTO,
                     SUM(VRPRODUTO)  -
                     NVL(SUM(VRDESCONTO), 0) +
                     NVL(SUM(VRIMPOSTO), 0) AS SOMAAF
                   FROM
                     (
                     SELECT
                        SUM(ITEMAUTF.QTPROGENTAF * ITEMAUTF.VRPREUNIAF) AS VRPRODUTO,
                        SUM((ITEMAUTF.QTPROGENTAF * ITEMAUTF.VRPREUNIAF *
                             ITEMAUTF.VRPERDESAF) / 100)                AS VRDESCONTO,
                        SUM(0) AS VRIMPOSTO, ITEMAUTF.CDPRODUTO AS PRODUTO
                      FROM ITEMAUTF,
                           AUTOFORNE
                      WHERE
                         AUTOFORNE.CDFILDEST  = ITEMAUTF.CDFILDEST AND
                         AUTOFORNE.CDFILLANC  = ITEMAUTF.CDFILLANC AND
                         AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN AND
                         ITEMAUTF.CDPRODUTO   = C_ITEM_LIMITE.CDPRODUTO AND
                         AUTOFORNE.DTMESAUTOFOR =
                                (SELECT DTMESAUTOFOR
                                 FROM AUTOFORNE
                                 WHERE
                                 AUTOFORNE.CDFILDEST = P_CDFILDEST   AND
                                 AUTOFORNE.CDFILLANC = P_CDFILLANC   AND
                                 AUTOFORNE.NRAUTOFORN= P_NRAUTOFORN) AND
                         AUTOFORNE.CDFILDEST = P_CDFILDEST AND
                         AUTOFORNE.CDOPERADOR = V_CDCOMPRADOR
                      GROUP BY ITEMAUTF.CDPRODUTO

                     UNION

                     SELECT
                        SUM(0) AS VRPRODUTO,
                        SUM(0) AS VRDESCONTO,
                        SUM(IMPITMAF.VRADIMPAF) AS VRIMPOSTO,
                        ITEMAUTF.CDPRODUTO AS PRODUTO

                     FROM
                        IMPITMAF,
                        ITEMAUTF,
                        AUTOFORNE
                     WHERE
                        IMPITMAF.CDFILDEST   = ITEMAUTF.CDFILDEST   AND
                        IMPITMAF.CDFILLANC   = ITEMAUTF.CDFILLANC   AND
                        IMPITMAF.NRAUTOFORN  = ITEMAUTF.NRAUTOFORN  AND
                        IMPITMAF.CDPRODUTO   = ITEMAUTF.CDPRODUTO   AND
                        IMPITMAF.CDMARCA     = ITEMAUTF.CDMARCA     AND
                        IMPITMAF.DTPROGENTAF = ITEMAUTF.DTPROGENTAF AND
                        AUTOFORNE.CDFILDEST  = ITEMAUTF.CDFILDEST    AND
                        AUTOFORNE.CDFILLANC  = ITEMAUTF.CDFILLANC    AND
                        AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN   AND
                        ITEMAUTF.CDPRODUTO   = C_ITEM_LIMITE.CDPRODUTO AND
                        AUTOFORNE.DTMESAUTOFOR =
                               (SELECT DTMESAUTOFOR
                                FROM AUTOFORNE
                                WHERE
                                 AUTOFORNE.CDFILDEST = P_CDFILDEST AND
                                 AUTOFORNE.CDFILLANC = P_CDFILLANC AND
                                 AUTOFORNE.NRAUTOFORN= P_NRAUTOFORN) AND
                        AUTOFORNE.CDFILDEST = P_CDFILDEST AND
                        AUTOFORNE.CDOPERADOR = V_CDCOMPRADOR
                     GROUP BY ITEMAUTF.CDPRODUTO
                     )
                     GROUP BY PRODUTO
                     ))
               WHERE  PRODUTO.CDPRODUTO = PRODUTO AND
                     (AUTOFORNE.CDFILDEST = P_CDFILDEST) AND
                     (AUTOFORNE.CDFILLANC = P_CDFILLANC) AND
                     (AUTOFORNE.NRAUTOFORN= P_NRAUTOFORN) AND
                     (AUTOFORNE.CDOPERADOR= LIMPRODAF.CDOPERADOR) AND
                     (P.CDPRODUTO = LIMPRODAF.CDPRODUTO) AND
                     P.CDARVPROD =
                                     (SELECT MAX(PR.CDARVPROD)
                                      FROM LIMPRODAF, PRODUTO PR
                                      WHERE PR.CDPRODUTO = LIMPRODAF.CDPRODUTO AND
                                            LIMPRODAF.CDOPERADOR = V_CDCOMPRADOR AND
                                            INSTR(PRODUTO.CDARVPROD, PR.CDARVPROD)= 1) AND
                     SOMAAF > LIMPRODAF.VRLIMPRAFMES;
               IF V_COUNT_LIMITE > 0 THEN
                  INSERT INTO INCONS_ITAF (CDFILDEST, CDFILLANC, NRAUTOFORN, CDPRODUTO, DTPROGENTAF, CDMARCA, CDINCONSITAF)
                  VALUES (P_CDFILDEST, P_CDFILLANC, P_NRAUTOFORN, C_ITEM_LIMITE.CDPRODUTO, C_ITEM_LIMITE.DTPROGENTAF, C_ITEM_LIMITE.CDMARCA, '13');
               END IF;
            END IF;
         END LOOP;
      END IF;
   END IF;
   IF V_COUNT_LIMITE > 0 THEN
      UPDATE AUTOFORNE
         SET IDAFFORALIM = 'S'
       WHERE AUTOFORNE.CDFILDEST  = P_CDFILDEST
         AND AUTOFORNE.CDFILLANC  = P_CDFILLANC
         AND AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN;
   END IF;

   /*Verificao de Inconsistncias de AFs*/

   V_COUNT_INCONSISTENCIA := 0;
   SELECT COUNT(1)
     INTO V_COUNT_INCONSISTENCIA
     FROM AUTOFORNE, FORNECEDOR,
        (SELECT SUM(QUANT) AS QUANT_TOTAL
         FROM
         (SELECT SUM(ITEMAUTF.QTPROGENTAF * PRODUTO.VRFATOCONV) AS QUANT
          FROM ITEMAUTF, AUTOFORNE, FORNECEDOR, PRODUTO, PRODUTO PRODESTO
          WHERE AUTOFORNE.CDFILDEST  = P_CDFILDEST
            AND AUTOFORNE.CDFILLANC  = P_CDFILLANC
            AND AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN
            AND AUTOFORNE.CDFILDEST  = ITEMAUTF.CDFILDEST
            AND AUTOFORNE.CDFILLANC  = ITEMAUTF.CDFILLANC
            AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN
            AND AUTOFORNE.CDFORNECED = FORNECEDOR.CDFORNECED
            AND ITEMAUTF.CDPRODUTO   = PRODUTO.CDPRODUTO
            AND PRODUTO.CDPRODESTO   = PRODESTO.CDPRODUTO
            AND PRODESTO.SGUNIDADE   =  FORNECEDOR.SGUNIDADE
          UNION ALL
          SELECT SUM(ITEMAUTF.QTPROGENTAF * PRODUTO.VRFATOCONV / CONVPRODUTO.VRFATOCONVES) AS QUANT
          FROM ITEMAUTF, AUTOFORNE, FORNECEDOR, PRODUTO, PRODUTO PRODESTO, CONVPRODUTO
          WHERE AUTOFORNE.CDFILDEST  = P_CDFILDEST
            AND AUTOFORNE.CDFILLANC  = P_CDFILLANC
            AND AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN
            AND AUTOFORNE.CDFILDEST  = ITEMAUTF.CDFILDEST
            AND AUTOFORNE.CDFILLANC  = ITEMAUTF.CDFILLANC
            AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN
            AND AUTOFORNE.CDFORNECED = FORNECEDOR.CDFORNECED
            AND ITEMAUTF.CDPRODUTO   = PRODUTO.CDPRODUTO
            AND PRODUTO.CDPRODESTO   =  PRODESTO.CDPRODUTO
            AND PRODESTO.SGUNIDADE   <> FORNECEDOR.SGUNIDADE
            AND CONVPRODUTO.CDPRODUTO = PRODUTO.CDPRODESTO
            AND CONVPRODUTO.SGUNIDADE = FORNECEDOR.SGUNIDADE)
         )
   WHERE AUTOFORNE.CDFILDEST =  P_CDFILDEST
     AND AUTOFORNE.CDFILLANC =  P_CDFILLANC
     AND AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN
     AND AUTOFORNE.CDFORNECED = FORNECEDOR.CDFORNECED
     AND QUANT_TOTAL < FORNECEDOR.QTMINAUTFOT
     AND NOT EXISTS(SELECT 1
                      FROM MINFORNREG, FILIAL
                      WHERE FILIAL.CDFILIAL = AUTOFORNE.CDFILDEST
                        AND MINFORNREG.CDREGIAO = FILIAL.CDREGIAO
                        AND MINFORNREG.CDFORNECED = AUTOFORNE.CDFORNECED
                        AND MINFORNREG.QTMINFORNREG >= 0
                        AND MINFORNREG.QTMINFORNREG IS NOT NULL);

   IF V_COUNT_INCONSISTENCIA > 0 THEN
      INSERT INTO INCONS_AF (CDFILDEST, CDFILLANC, NRAUTOFORN, CDINCONSAF)
      VALUES (P_CDFILDEST, P_CDFILLANC, P_NRAUTOFORN, '10');
      UPDATE AUTOFORNE
         SET IDSITUATUAAF = '1'
       WHERE AUTOFORNE.CDFILDEST  = P_CDFILDEST
         AND AUTOFORNE.CDFILLANC  = P_CDFILLANC
         AND AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN
         AND AUTOFORNE.IDSITUATUAAF IS NULL;
   END IF;

   V_COUNT_INCONSISTENCIA := 0;
   SELECT COUNT(1)
     INTO V_COUNT_INCONSISTENCIA
   FROM AUTOFORNE, MINFORNREG, FILIAL,
        (SELECT SUM(QUANT) AS QUANT_TOTAL
         FROM
         (SELECT SUM(ITEMAUTF.QTPROGENTAF * PRODUTO.VRFATOCONV) AS QUANT
          FROM ITEMAUTF, AUTOFORNE, FORNECEDOR, PRODUTO, PRODUTO PRODESTO
          WHERE AUTOFORNE.CDFILDEST  = P_CDFILDEST
            AND AUTOFORNE.CDFILLANC  = P_CDFILLANC
            AND AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN
            AND AUTOFORNE.CDFILDEST  = ITEMAUTF.CDFILDEST
            AND AUTOFORNE.CDFILLANC  = ITEMAUTF.CDFILLANC
            AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN
            AND AUTOFORNE.CDFORNECED = FORNECEDOR.CDFORNECED
            AND ITEMAUTF.CDPRODUTO   = PRODUTO.CDPRODUTO
            AND PRODUTO.CDPRODESTO   = PRODESTO.CDPRODUTO
            AND PRODESTO.SGUNIDADE   =  FORNECEDOR.SGUNIDADE
          UNION ALL
          SELECT SUM(ITEMAUTF.QTPROGENTAF * PRODUTO.VRFATOCONV / CONVPRODUTO.VRFATOCONVES) AS QUANT
          FROM ITEMAUTF, AUTOFORNE, FORNECEDOR, PRODUTO, PRODUTO PRODESTO, CONVPRODUTO
          WHERE AUTOFORNE.CDFILDEST  = P_CDFILDEST
            AND AUTOFORNE.CDFILLANC  = P_CDFILLANC
            AND AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN
            AND AUTOFORNE.CDFILDEST  = ITEMAUTF.CDFILDEST
            AND AUTOFORNE.CDFILLANC  = ITEMAUTF.CDFILLANC
            AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN
            AND AUTOFORNE.CDFORNECED = FORNECEDOR.CDFORNECED
            AND ITEMAUTF.CDPRODUTO   = PRODUTO.CDPRODUTO
            AND PRODUTO.CDPRODESTO   =  PRODESTO.CDPRODUTO
            AND PRODESTO.SGUNIDADE   <> FORNECEDOR.SGUNIDADE
            AND CONVPRODUTO.CDPRODUTO = PRODUTO.CDPRODESTO
            AND CONVPRODUTO.SGUNIDADE = FORNECEDOR.SGUNIDADE) QTDE
         ) QTDETOTAL

   WHERE AUTOFORNE.CDFILDEST  = P_CDFILDEST
     AND AUTOFORNE.CDFILLANC  = P_CDFILLANC
     AND AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN
     AND AUTOFORNE.CDFILDEST  = FILIAL.CDFILIAL
     AND AUTOFORNE.CDFORNECED = MINFORNREG.CDFORNECED
     AND FILIAL.CDREGIAO      = MINFORNREG.CDREGIAO
     AND QUANT_TOTAL < MINFORNREG.QTMINFORNREG;

   IF V_COUNT_INCONSISTENCIA > 0 THEN
      INSERT INTO INCONS_AF (CDFILDEST, CDFILLANC, NRAUTOFORN, CDINCONSAF)
      VALUES (P_CDFILDEST, P_CDFILLANC, P_NRAUTOFORN, '18');
      UPDATE AUTOFORNE
         SET IDSITUATUAAF = '1'
       WHERE AUTOFORNE.CDFILDEST  = P_CDFILDEST
         AND AUTOFORNE.CDFILLANC  = P_CDFILLANC
         AND AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN
         AND AUTOFORNE.IDSITUATUAAF IS NULL;
   END IF;

   V_COUNT_INCONSISTENCIA := 0;
   SELECT COUNT(1)
     INTO V_COUNT_INCONSISTENCIA
     FROM AUTOFORNE, FORNECEDOR
    WHERE AUTOFORNE.CDFILDEST = P_CDFILDEST
      AND AUTOFORNE.CDFILLANC = P_CDFILLANC
      AND AUTOFORNE.NRAUTOFORN= P_NRAUTOFORN
      AND AUTOFORNE.CDFORNECED= FORNECEDOR.CDFORNECED
      AND AUTOFORNE.VRTOTALAF < FORNECEDOR.VRMINAUTFOR
      AND NOT EXISTS(SELECT MINFORNREG.CDREGIAO
                       FROM MINFORNREG, FILIAL
                      WHERE FILIAL.CDFILIAL = AUTOFORNE.CDFILDEST
                        AND MINFORNREG.CDREGIAO = FILIAL.CDREGIAO
                        AND MINFORNREG.CDFORNECED = AUTOFORNE.CDFORNECED
                        AND MINFORNREG.VRMINFORNREG >= 0
                        AND MINFORNREG.VRMINFORNREG IS NOT NULL);

   IF V_COUNT_INCONSISTENCIA > 0 THEN
      INSERT INTO INCONS_AF (CDFILDEST, CDFILLANC, NRAUTOFORN, CDINCONSAF)
      VALUES (P_CDFILDEST, P_CDFILLANC, P_NRAUTOFORN, '11');
      UPDATE AUTOFORNE
         SET IDSITUATUAAF = '1'
       WHERE AUTOFORNE.CDFILDEST  = P_CDFILDEST
         AND AUTOFORNE.CDFILLANC  = P_CDFILLANC
         AND AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN
         AND AUTOFORNE.IDSITUATUAAF IS NULL;
   END IF;

   V_COUNT_INCONSISTENCIA := 0;
   SELECT COUNT(1)
     INTO V_COUNT_INCONSISTENCIA
     FROM AUTOFORNE, MINFORNREG, FILIAL
     WHERE AUTOFORNE.CDFILDEST  = P_CDFILDEST
       AND AUTOFORNE.CDFILLANC  = P_CDFILLANC
       AND AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN
       AND AUTOFORNE.CDFILDEST  = FILIAL.CDFILIAL
       AND AUTOFORNE.CDFORNECED = MINFORNREG.CDFORNECED
       AND FILIAL.CDREGIAO      = MINFORNREG.CDREGIAO
       AND AUTOFORNE.VRTOTALAF  < MINFORNREG.VRMINFORNREG;
   IF V_COUNT_INCONSISTENCIA > 0 THEN
      INSERT INTO INCONS_AF (CDFILDEST, CDFILLANC, NRAUTOFORN, CDINCONSAF)
      VALUES (P_CDFILDEST, P_CDFILLANC, P_NRAUTOFORN, '19');
      UPDATE AUTOFORNE
         SET IDSITUATUAAF = '1'
       WHERE AUTOFORNE.CDFILDEST  = P_CDFILDEST
         AND AUTOFORNE.CDFILLANC  = P_CDFILLANC
         AND AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN
         AND AUTOFORNE.IDSITUATUAAF IS NULL;
   END IF;

   /*Verificao de Inconsistncias de Itens de AFs*/
   SELECT NVL(CDFILCENTCMP, CDFILIAL) CDFILCENTCMP
     INTO V_CDFILCENTCMP
     FROM FILIAL
    WHERE CDFILIAL = P_CDFILDEST;

   SELECT MAX(IDQTCOTPROD), MAX(IDINCONSPRECSUP)
     INTO V_IDQTCOTPROD, V_IDINCONSPRECSUP
     FROM PARASUPRI
    WHERE CDFILIAL = V_CDFILCENTCMP;

    FOR C_ITEM IN
      (SELECT DISTINCT ITEMAUTF.CDPRODUTO, PRODUTO.NMPRODUTO, PRODUTO.CDARVPROD, PRODUTO.CDPRODESTO, ITEMAUTF.VRPREUNIAF, NVL(PRODUTO.VRFATOCONV, 1) VRFATOCONV
         FROM ITEMAUTF, PRODUTO
        WHERE PRODUTO.CDPRODUTO   = ITEMAUTF.CDPRODUTO
          AND ITEMAUTF.CDFILDEST  = P_CDFILDEST
          AND ITEMAUTF.CDFILLANC  = P_CDFILLANC
          AND ITEMAUTF.NRAUTOFORN = P_NRAUTOFORN)
    LOOP
       V_COUNT_INCONSISTENCIA := 0;
       SELECT COUNT(1)
         INTO V_COUNT_INCONSISTENCIA
         FROM PRODFORN, AUTOFORNE, PRODUTO, PRODUTO PROD,
        (
          SELECT PRODUTO,
                 SUM(QUANT) AS QUANT_PROD
          FROM
           (  SELECT SUM(ITEMAUTF.QTPROGENTAF * PRODUTO.VRFATOCONV) AS QUANT,
                     ITEMAUTF.CDPRODUTO AS PRODUTO
              FROM ITEMAUTF, AUTOFORNE, PRODFORN, PRODUTO , PRODUTO P, PRODUTO PRODESTO
              WHERE  AUTOFORNE.CDFILDEST  = P_CDFILDEST          AND
                     AUTOFORNE.CDFILLANC  = P_CDFILLANC          AND
                     AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN         AND
                     AUTOFORNE.CDFILDEST  = ITEMAUTF.CDFILDEST    AND
                     AUTOFORNE.CDFILLANC  = ITEMAUTF.CDFILLANC    AND
                     AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN   AND
                     AUTOFORNE.CDFORNECED = PRODFORN.CDFORNECED   AND
                     ITEMAUTF.CDPRODUTO   = PRODUTO.CDPRODUTO     AND
                     ITEMAUTF.CDPRODUTO   = C_ITEM.CDPRODUTO      AND
                     PRODUTO.CDPRODESTO   = PRODESTO.CDPRODESTO   AND
                     PRODESTO.SGUNIDADE   = PRODFORN.SGUNIDADE    AND
                     P.CDPRODUTO          = PRODFORN.CDPRODUTO    AND
                     P.CDARVPROD   =
                            ( SELECT MAX(PR.CDARVPROD)
                              FROM PRODFORN, PRODUTO PR
                              WHERE
                                PRODFORN.CDPRODUTO   = PR.CDPRODUTO AND
                                AUTOFORNE.CDFORNECED = PRODFORN.CDFORNECED AND
                                PRODUTO.CDARVPROD LIKE PR.CDARVPROD || '%'
                             )
              GROUP BY ITEMAUTF.CDPRODUTO, PRODUTO.CDARVPROD
              UNION
              SELECT SUM(ITEMAUTF.QTPROGENTAF * PRODUTO.VRFATOCONV / CONVPRODUTO.VRFATOCONVES) AS QUANT,
                     ITEMAUTF.CDPRODUTO AS PRODUTO
              FROM ITEMAUTF, AUTOFORNE, PRODFORN, PRODUTO, PRODUTO P, PRODUTO PRODESTO, CONVPRODUTO
              WHERE AUTOFORNE.CDFILDEST  = P_CDFILDEST          AND
                    AUTOFORNE.CDFILLANC  = P_CDFILLANC          AND
                    AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN         AND
                    AUTOFORNE.CDFILDEST  = ITEMAUTF.CDFILDEST    AND
                    AUTOFORNE.CDFILLANC  = ITEMAUTF.CDFILLANC    AND
                    AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN   AND
                    AUTOFORNE.CDFORNECED = PRODFORN.CDFORNECED   AND
                    ITEMAUTF.CDPRODUTO   = PRODUTO.CDPRODUTO     AND
                    ITEMAUTF.CDPRODUTO   = C_ITEM.CDPRODUTO      AND
                    PRODUTO.CDPRODESTO   = PRODESTO.CDPRODUTO    AND
                    PRODESTO.SGUNIDADE  <> PRODFORN.SGUNIDADE    AND
                    CONVPRODUTO.CDPRODUTO = PRODUTO.CDPRODESTO   AND
                    CONVPRODUTO.SGUNIDADE = PRODFORN.SGUNIDADE   AND
                    P.CDPRODUTO          = PRODFORN.CDPRODUTO    AND
                    P.CDARVPROD   =
                           ( SELECT MAX(PR.CDARVPROD)
                             FROM PRODFORN, PRODUTO PR
                             WHERE
                               PRODFORN.CDPRODUTO   = PR.CDPRODUTO AND
                               AUTOFORNE.CDFORNECED = CDFORNECED    AND
                               PRODUTO.CDARVPROD LIKE PR.CDARVPROD || '%'
                            )
              GROUP BY ITEMAUTF.CDPRODUTO, PRODUTO.CDARVPROD
           )
          GROUP BY PRODUTO
        )
       WHERE  (PRODUTO = PRODUTO.CDPRODUTO) AND
              (AUTOFORNE.CDFILDEST  = P_CDFILDEST)       AND
              (AUTOFORNE.CDFILLANC  = P_CDFILLANC)       AND
              (AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN) AND
              (AUTOFORNE.CDFORNECED = PRODFORN.CDFORNECED) AND
              (PROD.CDPRODUTO = PRODFORN.CDPRODUTO) AND
              (PROD.CDARVPROD =
                        (SELECT MAX(PR.CDARVPROD)
                         FROM PRODFORN, PRODUTO PR
                         WHERE
                           (PR.CDPRODUTO = PRODFORN.CDPRODUTO) AND
                           (AUTOFORNE.CDFORNECED = CDFORNECED)  AND
                           (PRODUTO.CDARVPROD LIKE PR.CDARVPROD || '%'))) AND
              (QUANT_PROD < PRODFORN.QTMINAF);
       IF V_COUNT_INCONSISTENCIA > 0 THEN
          INSERT INTO INCONS_ITAF (CDFILDEST, CDFILLANC, NRAUTOFORN, CDPRODUTO, DTPROGENTAF, CDMARCA, CDINCONSITAF)
          SELECT CDFILDEST, CDFILLANC, NRAUTOFORN, CDPRODUTO, DTPROGENTAF, CDMARCA, '14'
            FROM ITEMAUTF
           WHERE ITEMAUTF.CDFILDEST = P_CDFILDEST
             AND ITEMAUTF.CDFILLANC = P_CDFILLANC
             AND ITEMAUTF.NRAUTOFORN = P_NRAUTOFORN
             AND ITEMAUTF.CDPRODUTO = C_ITEM.CDPRODUTO;

          UPDATE AUTOFORNE
             SET IDSITUATUAAF = '1'
           WHERE AUTOFORNE.CDFILDEST  = P_CDFILDEST
             AND AUTOFORNE.CDFILLANC  = P_CDFILLANC
             AND AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN
             AND AUTOFORNE.IDSITUATUAAF IS NULL;
       END IF;

       V_COUNT_INCONSISTENCIA := 0;
       SELECT COUNT(1)
         INTO V_COUNT_INCONSISTENCIA
         FROM PARCMPSUP, PRODFORNCOMP, AUTOFORNE, ITEMAUTF, MARCA
       WHERE ITEMAUTF.CDFILDEST  = P_CDFILDEST
         AND ITEMAUTF.CDFILLANC  = P_CDFILLANC
         AND ITEMAUTF.NRAUTOFORN = P_NRAUTOFORN
         AND ITEMAUTF.CDPRODUTO  = C_ITEM.CDPRODUTO
         AND AUTOFORNE.CDFILDEST  = ITEMAUTF.CDFILDEST
         AND AUTOFORNE.CDFILLANC  = ITEMAUTF.CDFILLANC
         AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN
         AND PRODFORNCOMP.CDFORNECED = AUTOFORNE.CDFORNECED
         AND PRODFORNCOMP.CDPRODCOMPL = ITEMAUTF.CDPRODUTO
         AND PARCMPSUP.CDFILIAL = ITEMAUTF.CDFILDEST
         AND PARCMPSUP.IDUTARCMPFOR = 'S'
         AND MOD(ITEMAUTF.QTPROGENTAF, PRODFORNCOMP.VRARREDCMPFO) <> 0
         AND ITEMAUTF.CDMARCA = MARCA.CDMARCA;

       IF V_COUNT_INCONSISTENCIA > 0 THEN
          INSERT INTO INCONS_ITAF (CDFILDEST, CDFILLANC, NRAUTOFORN, CDPRODUTO, DTPROGENTAF, CDMARCA, CDINCONSITAF)
          SELECT CDFILDEST, CDFILLANC, NRAUTOFORN, CDPRODUTO, DTPROGENTAF, CDMARCA, '15'
            FROM ITEMAUTF
           WHERE ITEMAUTF.CDFILDEST = P_CDFILDEST
             AND ITEMAUTF.CDFILLANC = P_CDFILLANC
             AND ITEMAUTF.NRAUTOFORN = P_NRAUTOFORN
             AND ITEMAUTF.CDPRODUTO = C_ITEM.CDPRODUTO;
          UPDATE AUTOFORNE
             SET IDSITUATUAAF = '1'
           WHERE AUTOFORNE.CDFILDEST  = P_CDFILDEST
             AND AUTOFORNE.CDFILLANC  = P_CDFILLANC
             AND AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN
             AND AUTOFORNE.IDSITUATUAAF IS NULL;
       END IF;

       V_COUNT_INCONSISTENCIA := 0;
       SELECT COUNT(1)
         INTO V_COUNT_INCONSISTENCIA
         FROM PRODPREFMED, PRODUTO
        WHERE PRODPREFMED.CDFILIAL = P_CDFILDEST
          AND PRODPREFMED.CDPRODUTO = C_ITEM.CDPRODESTO
          AND PRODPREFMED.CDPRODPREF = PRODUTO.CDPRODUTO;
       IF V_COUNT_INCONSISTENCIA > 0 THEN
          INSERT INTO INCONS_ITAF (CDFILDEST, CDFILLANC, NRAUTOFORN, CDPRODUTO, DTPROGENTAF, CDMARCA, CDINCONSITAF)
          SELECT CDFILDEST, CDFILLANC, NRAUTOFORN, CDPRODUTO, DTPROGENTAF, CDMARCA, '17'
            FROM ITEMAUTF
           WHERE ITEMAUTF.CDFILDEST = P_CDFILDEST
             AND ITEMAUTF.CDFILLANC = P_CDFILLANC
             AND ITEMAUTF.NRAUTOFORN = P_NRAUTOFORN
             AND ITEMAUTF.CDPRODUTO = C_ITEM.CDPRODUTO;
          UPDATE AUTOFORNE
             SET IDSITUATUAAF = '1'
           WHERE AUTOFORNE.CDFILDEST  = P_CDFILDEST
             AND AUTOFORNE.CDFILLANC  = P_CDFILLANC
             AND AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN
             AND AUTOFORNE.IDSITUATUAAF IS NULL;
       END IF;

       IF V_IDQTCOTPROD = 'S' THEN
          FOR C_QUANTCOTPROD IN
            (SELECT QUANTCOTPROD.VRQTDCOTACAO
               FROM QUANTCOTPROD
              WHERE CDFILIAL = V_CDFILCENTCMP
                AND CDPRODUTO = (SELECT MAX(B.CDARVPROD)
                                   FROM QUANTCOTPROD A, PRODUTO B
                                  WHERE A.CDPRODUTO = B.CDPRODUTO
                                    AND A.CDFILIAL  = V_CDFILCENTCMP
                                    AND INSTR(C_ITEM.CDARVPROD, B.CDARVPROD) = 1))
          LOOP
             FOR C_DTPROGENTAF IN
               (SELECT DISTINCT DTPROGENTAF
                  FROM ITEMAUTF
                 WHERE CDFILDEST  = P_CDFILDEST
                   AND CDFILLANC  = P_CDFILLANC
                   AND NRAUTOFORN = P_NRAUTOFORN
                   AND CDPRODUTO  = C_ITEM.CDPRODUTO)
             LOOP
                V_COUNT_INCONSISTENCIA := 0;
                SELECT COUNT(*) QTDCOTACAO
                  INTO V_COUNT_INCONSISTENCIA
                  FROM ITEMCOLE
                 WHERE CDPRODUTO = C_ITEM.CDPRODUTO
                   AND CDFILIAL  = V_CDFILCENTCMP
                   AND C_DTPROGENTAF.DTPROGENTAF BETWEEN DTINIVALITM AND DTFINVALITM
                   AND NOT EXISTS (SELECT 1
                                     FROM REFOREG
                                    WHERE ITEMCOLE.CDFORNECED = REFOREG.CDFORNECED
                                      AND ITEMCOLE.CDREGIAO   = REFOREG.CDREGIAO)
                   AND NOT EXISTS (SELECT 1
                                     FROM REFORFIL
                                    WHERE CDFILIAL   = P_CDFILDEST
                                      AND CDFORNECED = ITEMCOLE.CDFORNECED
                                      AND CDPERIENTR IS NULL)
                HAVING COUNT(*) > C_QUANTCOTPROD.VRQTDCOTACAO;
                IF V_COUNT_INCONSISTENCIA > 0 THEN
                   INSERT INTO INCONS_ITAF (CDFILDEST, CDFILLANC, NRAUTOFORN, CDPRODUTO, DTPROGENTAF, CDMARCA, CDINCONSITAF)
                   SELECT CDFILDEST, CDFILLANC, NRAUTOFORN, CDPRODUTO, DTPROGENTAF, CDMARCA, '20'
                     FROM ITEMAUTF
                    WHERE ITEMAUTF.CDFILDEST = P_CDFILDEST
                      AND ITEMAUTF.CDFILLANC = P_CDFILLANC
                      AND ITEMAUTF.NRAUTOFORN = P_NRAUTOFORN
                      AND ITEMAUTF.DTPROGENTAF = C_DTPROGENTAF.DTPROGENTAF
                      AND ITEMAUTF.CDPRODUTO = C_ITEM.CDPRODUTO;
                   UPDATE AUTOFORNE
                      SET IDSITUATUAAF = '1'
                    WHERE AUTOFORNE.CDFILDEST  = P_CDFILDEST
                      AND AUTOFORNE.CDFILLANC  = P_CDFILLANC
                      AND AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN
                      AND AUTOFORNE.IDSITUATUAAF IS NULL;
                END IF;
             END LOOP;
          END LOOP;
       END IF;

       V_COUNT_INCONSISTENCIA := 0;
       SELECT COUNT(1)
         INTO V_COUNT_INCONSISTENCIA
         FROM
            PRODUTO,
            (SELECT
             DISTINCT ITEMAUTF.CDPRODUTO AS PRODUTO,
                      ITEMAUTF.CDMARCA AS MARCA,
                      ITEMAUTF.CDSEGMARCA AS SEGMARCA,
                      AUTOFORNE.CDFORNECED AS FORNECEDOR,
                      PARTFILI.CDTIPPART AS PARTICULAR,
                      PARTFILI.CDMARCA AS PART_MARCA,
                      PARTFILI.CDFORNECED AS PART_FORN,
                      PARTFILI.CDPRODUTO AS PROD_PART
             FROM ITEMAUTF, AUTOFORNE, PARTFILI
             WHERE
               (ITEMAUTF.CDFILDEST   = P_CDFILDEST)        AND
               (ITEMAUTF.CDFILLANC   = P_CDFILLANC)        AND
               (ITEMAUTF.NRAUTOFORN  = P_NRAUTOFORN)       AND
               (ITEMAUTF.CDPRODUTO   = C_ITEM.CDPRODUTO)   AND
               (AUTOFORNE.CDFILDEST  = P_CDFILDEST)        AND
               (AUTOFORNE.CDFILLANC  = P_CDFILLANC)        AND
               (AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN)       AND
               (ITEMAUTF.CDPRODUTO   = PARTFILI.CDPRODUTO) AND
               (ITEMAUTF.CDFILDEST   = PARTFILI.CDFILIAL)  AND
               (PARTFILI.CDTIPPART   <> '4'  OR
                PARTFILI.NRCOLEPRECO IS NULL OR
                EXISTS (SELECT 1
                          FROM COLETAPR
                         WHERE COLETAPR.CDFILIAL    = PARTFILI.CDFILCOTA
                           AND COLETAPR.NRCOLEPRECO = PARTFILI.NRCOLEPRECO
                           AND ITEMAUTF.DTENTRITMSOL BETWEEN COLETAPR.DTINIVALCOL AND COLETAPR.DTFINVALCOL)
                )
             ) PROD
       WHERE (PRODUTO = PRODUTO.CDPRODUTO) AND
             (PRODUTO IS NOT NULL) AND
             (((PARTICULAR =  '1')    AND
              (PRODUTO = PROD_PART) AND
              ((MARCA  <> PART_MARCA) OR
              (SEGMARCA IS NOT NULL AND SEGMARCA <> PART_MARCA)) )  OR

             ((PARTICULAR = '2')  AND
               (NOT EXISTS(SELECT CDTIPPART
                           FROM PARTFILI
                           WHERE (CDFILIAL = P_CDFILDEST) AND
                                 (CDPRODUTO = PRODUTO) AND
                                 (CDTIPPART  = '2') AND
                                 (CDMARCA = MARCA))) AND
                NOT EXISTS
                  (SELECT CDTIPPART
                   FROM PARTFILI PMF
                   WHERE
                     PMF.CDFILIAL = P_CDFILDEST AND
                     PMF.CDPRODUTO = PRODUTO AND
                     PMF.CDMARCA  = MARCA AND
                     PMF.CDTIPPART = '8' AND
                     PMF.CDFORNECED = FORNECEDOR) ) OR

             ((PARTICULAR = '2')  AND
               (SEGMARCA IS NOT NULL) AND
               (NOT EXISTS(SELECT CDTIPPART
                           FROM PARTFILI
                           WHERE (CDFILIAL = P_CDFILDEST) AND
                                 (CDPRODUTO = PRODUTO) AND
                                 (CDTIPPART  = '2') AND
                                 (CDMARCA = SEGMARCA))) AND
                NOT EXISTS
                  (SELECT CDTIPPART
                   FROM PARTFILI PMF
                   WHERE
                     PMF.CDFILIAL = P_CDFILDEST AND
                     PMF.CDPRODUTO = PRODUTO AND
                     PMF.CDMARCA  = SEGMARCA AND
                     PMF.CDTIPPART = '8' AND
                     PMF.CDFORNECED = FORNECEDOR) ) OR

             ((PARTICULAR =  '3')    AND
              (PRODUTO = PROD_PART) AND
              ((MARCA  = PART_MARCA) OR
              (SEGMARCA IS NOT NULL AND SEGMARCA = PART_MARCA)))  OR

             ((PARTICULAR =  '4')    AND
              (PRODUTO = PROD_PART)  AND
              (FORNECEDOR <> PART_FORN))  OR

             ((PARTICULAR = '5')  AND
               (NOT EXISTS(SELECT CDTIPPART
                           FROM PARTFILI
                           WHERE (CDFILIAL = P_CDFILDEST) AND
                                 (CDPRODUTO = PRODUTO) AND
                                 (CDTIPPART  = '5') AND
                                 (CDFORNECED = FORNECEDOR))) AND
                NOT EXISTS
                  (SELECT CDTIPPART
                   FROM PARTFILI PMF
                   WHERE
                     PMF.CDFILIAL = P_CDFILDEST AND
                     PMF.CDPRODUTO = PRODUTO AND
                     PMF.CDMARCA  = MARCA AND
                     PMF.CDTIPPART = '8' AND
                     PMF.CDFORNECED = FORNECEDOR) ) OR

             ((PARTICULAR =  '6')    AND
              (PRODUTO = PROD_PART) AND
              (FORNECEDOR  = PART_FORN))  OR

             ((PARTICULAR =  '7')    AND
              (PRODUTO = PROD_PART) AND
              ((MARCA  <> PART_MARCA OR
               (SEGMARCA IS NOT NULL AND SEGMARCA <> PART_MARCA)) OR
              (FORNECEDOR <> PART_FORN)))  OR


             ((PARTICULAR = '8')  AND
               (NOT EXISTS(SELECT CDTIPPART
                           FROM PARTFILI
                           WHERE (CDFILIAL = P_CDFILDEST) AND
                                 (CDPRODUTO = PRODUTO) AND
                                 (CDTIPPART  = '8') AND
                                 (CDMARCA    = MARCA) AND
                                 (CDFORNECED = FORNECEDOR)))) OR

             ((PARTICULAR = '8')  AND
               (SEGMARCA IS NOT NULL) AND
               (NOT EXISTS(SELECT CDTIPPART
                           FROM PARTFILI
                           WHERE (CDFILIAL = P_CDFILDEST) AND
                                 (CDPRODUTO = PRODUTO) AND
                                 (CDTIPPART  = '8') AND
                                 (CDMARCA    = SEGMARCA) AND
                                 (CDFORNECED = FORNECEDOR)))) OR

             ((PARTICULAR =  '9')    AND
              (PRODUTO = PROD_PART) AND
              ((MARCA  = PART_MARCA) OR
              (SEGMARCA IS NOT NULL AND SEGMARCA = PART_MARCA)) AND
              (FORNECEDOR  = PART_FORN))
       );
       IF V_COUNT_INCONSISTENCIA > 0 THEN
          INSERT INTO INCONS_ITAF (CDFILDEST, CDFILLANC, NRAUTOFORN, CDPRODUTO, DTPROGENTAF, CDMARCA, CDINCONSITAF)
          SELECT CDFILDEST, CDFILLANC, NRAUTOFORN, CDPRODUTO, DTPROGENTAF, CDMARCA, '16'
            FROM ITEMAUTF
           WHERE ITEMAUTF.CDFILDEST = P_CDFILDEST
             AND ITEMAUTF.CDFILLANC = P_CDFILLANC
             AND ITEMAUTF.NRAUTOFORN = P_NRAUTOFORN
             AND ITEMAUTF.CDPRODUTO = C_ITEM.CDPRODUTO;
          UPDATE AUTOFORNE
             SET IDSITUATUAAF = '1'
           WHERE AUTOFORNE.CDFILDEST  = P_CDFILDEST
             AND AUTOFORNE.CDFILLANC  = P_CDFILLANC
             AND AUTOFORNE.NRAUTOFORN = P_NRAUTOFORN
             AND AUTOFORNE.IDSITUATUAAF IS NULL;
       END IF;
    END LOOP;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('VERIFICA_INCONS_AFS','5.50.xxx'); END;
/
