import Vue from 'vue';
import Router from 'vue-router';
import { Config } from '@zeedhi/core';
import { ZdPage } from '@zeedhi/vue';
import Store from './store';

Vue.use(Router);

const router = new Router({
  mode: 'history',
  base: process.env.BASE_URL,
  routes: [
    {
      path: '/',
      name: 'home',
      component: () => import('./views/Home.vue'),
    },
    {
      path: '/zeedhi',
      name: 'zeedhi',
      component: ZdPage,
      props: () => ({
        path: 'zeedhi',
        local: true,
      }),
    },
    {
      path: '/login',
      name: 'login',
      component: ZdPage,
      props: () => ({
        path: 'login',
        local: true,
      }),
    },
    {
      path: '/dashboard',
      name: 'dashboard',
      component: ZdPage,
      props: () => ({
        path: 'layout_dashboard',
        local: true,
      }),
    },
    {
      path: '/notificacao',
      name: 'notificacao',
      component: ZdPage,
      props: () => ({
        path: 'layout_notificacao',
        local: true,
      }),
    },
    {
      path: '/modules/:module/:page',
      name: 'microservice',
      component: () => import('./views/Microservice.vue'),
    },
    {
      path: '*',
      component: ZdPage,
      props: {
        path: 'notfound',
        local: true,
      },
    },
  ],
});

router.beforeEach((to, from, next) => {
  if (to.path !== Config.env.loginRoutePath && !localStorage.getItem('LOGIN_TOKEN')) {
    next(Config.env.loginRoutePath);
  } else if (to.path === Config.env.loginRoutePath && localStorage.getItem('LOGIN_TOKEN')) {
    next(Config.env.baseUrl);
  } else {
    next();
  }
});

router.afterEach((to, from) => {
  const htmlElement = document.getElementsByTagName('html')[0];
  if (to.name === 'microservice') {
    htmlElement.setAttribute('microservice', '');
    Store.commit('setRouterParams', to.params);
    const frame = (document.getElementById('microservice-frame') as HTMLIFrameElement);
    if (frame && frame.contentWindow && to.path.split('/')[2] === from.path.split('/')[2]) {
      frame.contentWindow.postMessage({
        type: 'microservice-route-change',
        routerParams: to.params,
      }, `${Config.env.modules[to.path.split('/')[2]].baseUrl}`);
    }
    window.document.title = `${Config.env.product.name} - ${to.params.page}`;
  } else {
    htmlElement.removeAttribute('microservice');
    window.document.title = Config.env.product.name;
  }

  if (to.name === 'login') {
    htmlElement.setAttribute('login', '');
  } else {
    htmlElement.removeAttribute('login');
  }
});

export const { VUE_APP_BASE_URL } = process.env;

export const getRoutePath = () => {
  const { currentRoute } = router;
  const { path } = currentRoute;
  return path;
};

export const getRouteParams = () => {
  const { currentRoute } = router;
  const { params } = currentRoute;
  return params;
};

export default router;
